#!/bin/sh
if [ $# -gt 1 ] || ( [ $# -eq 1 ] && [ "$1" != "-n" ] ); then
 echo "use as $0 [-n]"
 exit 1
fi

CDIR=`pwd`
#####try some sanity checks
if [ "`type -path gnome-config`" = "" ]; then
 if [ "$1" = "-n" ]; then
  echo warning: gnome installation is not found
  if [ "$prefix" = "" ]; then
   echo error: you must specify a non-empty prefix
   exit 1
  fi
 else
  echo error: gnome installation is not found
  exit 1
 fi
else
 try=`gnome-config --prefix`
 prefix=${prefix:-$try}
 if [ "$try" != "$prefix" ]; then
  if [ "$1" = "-n" ]; then
   echo warning: your gnome is installed to $try while you are installing to $prefix
  else
   echo error: your gnome is installed to $try while you are installing to $prefix
   exit 1
  fi
 fi
fi
######end of sanity checks
echo install root is ${INSTALL_ROOT:=""}
echo prefix is ${prefix}
echo fontdir is ${FONTDIR:=/usr/X11R6/lib/X11/fonts/misc}
######install now
mkdir -p $INSTALL_ROOT${prefix}/share/themes
##standard Gnome package already contains themes Stone and BrushedMetal
##they are different from those to be installed, we will back up them
[ -e $INSTALL_ROOT${prefix}/share/themes/Stone ] && mv \
	$INSTALL_ROOT${prefix}/share/themes/Stone \
	$INSTALL_ROOT${prefix}/share/themes/Stone.bak
[ -e $INSTALL_ROOT${prefix}/share/themes/BrushedMetal ] && mv \
	$INSTALL_ROOT${prefix}/share/themes/BrushedMetal \
	$INSTALL_ROOT${prefix}/share/themes/BrushedMetal.bak

##first we fix "wrong" archives
LIST="`file *z|grep -v gzip|grep bzip2| awk '{print $1}'|cut -f1 -d :`"
for i in $LIST
do
 f="`basename $i .tgz`"
 f="`basename $f .gz`"
 f="`basename $f .tar`"
 echo mv "$i" "$f.tar.bz2"
 mv "$i" "$f.tar.bz2"
done

LIST="`file *z|grep -v gzip|grep "tar archive"|awk '{print $1}'|cut -f1 -d :`"
for i in $LIST
do
 f="`basename $i .tgz`"
 f="`basename $f .gz`"
 f="`basename $f .tar`"
 echo mv "$i" "$f.tar"
 mv "$i" "$f.tar"
done

ls *z > /dev/null 2>&1
if [ $? -eq 0 ]; then
 for i in *z
 do
  echo installing $i
  tar -C $INSTALL_ROOT${prefix}/share/themes  -x -z  -f "$i"
 done
fi

ls *.tar > /dev/null 2>&1
if [ $? -eq 0 ]; then
 for i in *.tar
 do
  echo installing $i
  tar -C $INSTALL_ROOT${prefix}/share/themes  -x -f "$i"
 done
fi

ls *.bz2 > /dev/null 2>&1
if [ $? -eq 0 ]; then
 for i in *.bz2
 do
  echo installing $i
  bunzip2 -c "$i" | tar -C $INSTALL_ROOT${prefix}/share/themes  -x -f -
 done
fi

cd $INSTALL_ROOT${prefix}/share/themes

#special handling
for i in Blackness OldWood RatsTheme Tiger lcdtheme macos8.5
do
 mkdir gtk
 mv $i/* gtk
 mv gtk $i
 for j in $i/gtk/README* $i/gtk/Readme*
 do
  [ -e $j ] && mv $j $i
 done
done
#end of special handling 

#fix permissions and ownerships
chown -R root.root ./
for i in *
do
 chmod 755 $i
 chmod 644 $i/*
 chmod 755 $i/gtk
 chmod 644 $i/gtk/*
 chmod -R a+r $i
done
#chmod 755 `find ./ -type d -name GNOME-tiles`
#end of fix permissions and ownerships

#clean up trash
rm -rf `find ./ -type d  -name .xvpics`
rm -rf `find ./ -type f  -name  .directory`
rm -f `find ./ -type f  -name '.gtkrc*'`
rm -f `find ./ -type f  -name '*.bak'`
rm -f `find ./ -type f  -name '*.old'`
rm -f `find ./ -type f  -name '*~'`
#end clean up trash

##fix references to stupid paths
if [ -e Muffy/gtk/backgroud.xpm ]; then
 mv Muffy/gtk/backgroud.xpm Muffy/gtk/background.xpm
fi
LIST=`find ./ -name gtkrc`
LIST=`grep -l '^pixmap_path' $LIST`
for i in $LIST
do
 sed -e "s/^pixmap_path/#pixmap_path/" $i > $i.fixed
 mv $i.fixed $i
done

LIST=`find ./ -name gtkrc`
LIST=`grep -l '^module_path' $LIST`
for i in $LIST
do
 sed -e "s/^module_path/#module_path/" $i > $i.fixed
 mv $i.fixed $i
done
##end of fix references to stupid paths

###########now build extra engines###################
cd $CDIR/engines
mkdir -p compile
for i in GTKstep-1.2.tar.gz Gnome-Look-1.2.x.tar.gz ThinIce-1.2.tar.gz \
	Warp-1.2.x.tar.gz Zenith-1.2.tar.gz buffy-0.2-1.2.tar.gz \
	clean-1.2.x.tar.gz gtkstep-pastel-1.2.tar.gz
do
 tar -C compile -x -z -vv -f $i
done

cd compile
for i in *
do
 cd $i
 rm -f config.cache
 ./configure --prefix=${prefix}
 make -j4 CFLAGS="-O2 -m486" ACLOCAL="aclocal -I ${prefix}/share/aclocal"
 if [ $? -ne 0 ]; then
  exit 1
 fi
 make install prefix=$INSTALL_ROOT${prefix}
 cd ..
done 

#compile and install Xenophilia
cd ..
tar xzvvf Xenophilia-0.2-1.2.tar.gz
cd Xenophilia-0.2
make -j8
if [ $? -ne 0 ]; then
  exit 1
fi    
make install PREFIX=$INSTALL_ROOT${prefix}
mkdir -p $INSTALL_ROOT${FONTDIR}
install -m644 *.pcf.gz $INSTALL_ROOT${FONTDIR}
##create fonts.dir if not a package install
if [ "a$INSTALL_ROOT" = "a" ] && [ `type -path mkfontdir` != "" ]; then 
 mkfontdir $INSTALL_ROOT${FONTDIR}
fi
cd ..

#compile and install stone theme
tar -C $INSTALL_ROOT${prefix}/share/themes -x -z -vv -f Stone-1.2.tar.gz 
rm -f $INSTALL_ROOT${prefix}/share/themes/Stone/libstone*
mkdir Stone
tar -C Stone -x -z -vv -f stone-engine.tgz
cd Stone
patch -p0 < gtk-engines-0.5.patch
cd pixmap
./configure --prefix=${prefix}
make -j CFLAGS="-O2 -m486"
if [ $? -ne 0 ]; then
  exit 1
fi    
make install prefix=$INSTALL_ROOT${prefix}

##standard Gnome package already contains themes Stone and BrushedMetal
##they are different from those just installed, so we will change the names
mv $INSTALL_ROOT${prefix}/share/themes/Stone \
        $INSTALL_ROOT${prefix}/share/themes/Stone1
mv  $INSTALL_ROOT${prefix}/share/themes/BrushedMetal \
        $INSTALL_ROOT${prefix}/share/themes/BrushedMetal1

##if we have backed up anything, restore it
[ -e $INSTALL_ROOT${prefix}/share/themes/Stone.bak ] && mv \
        $INSTALL_ROOT${prefix}/share/themes/Stone.bak \
        $INSTALL_ROOT${prefix}/share/themes/Stone
[ -e $INSTALL_ROOT${prefix}/share/themes/BrushedMetal.bak ] && mv \
        $INSTALL_ROOT${prefix}/share/themes/BrushedMetal.bak \
        $INSTALL_ROOT${prefix}/share/themes/BrushedMetal
exit 0
